

from mmisdk.common.base_model import BaseModel


class BitgoResponseMeta(BaseModel):
    reqId: str
